@@ -26,6 +26,8 @@ from biomaj.process.processfactory import RemoveProcessFactory, PreProcessFactor
 from biomaj_zipkin.zipkin import Zipkin
 from yapsy.PluginManager import PluginManager
 
+from packaging.version import parse
+
 
 class Workflow(object):
     """
@@ -516,25 +518,16 @@ class UpdateWorkflow(Workflow):
         Try to find most release from releases input array
         '''
         release = releases[0]
-        releaseElts = re.split(r'\.|-', release)
+        release_version = parse(release)
         logging.debug('found a release %s' % (release))
         for rel in releases:
             if rel == release:
                 continue
             logging.debug('compare next release %s' % (rel))
-            relElts = re.split(r'\.|-', rel)
-            index = 0
-            for relElt in relElts:
-                logging.debug("compare release major,minor,etc. : %s >? %s" % (relElt, releaseElts[index]))
-                try:
-                    if int(relElt) > int(releaseElts[index]):
-                        release = rel
-                        logging.debug("found newer release %s" % (rel))
-                        break
-                except ValueError:
-                    pass
-                finally:
-                    index += 1
+            next_release = parse(rel)
+            if next_release > release_version:
+                release = rel
+                release_version = next_release
         return release
 
     def wf_release(self):
@@ -1663,9 +1656,7 @@ class UpdateWorkflow(Workflow):
                 nb_try = 1
                 origFile = self.session.get_offline_directory() + '/' + file['save_as']
                 is_archive = False
-                if origFile.endswith('.tar.gz'):
-                    is_archive = True
-                elif origFile.endswith('.tar'):
+                if origFile.endswith(('.tar.gz', '.tar', '.tgz')):
                     is_archive = True
                 elif origFile.endswith('.bz2'):
                     is_archive = True
